Notice
------
This library has been renamed to [`mqrpy`](https://pypi.org/project/mqrpy/).

---

MQR
---
This library is a python toolkit for manufacturing and design statistics.

Installation
------------
This package (`mqr-quality`) has no content except a single dependency on `mqrpy`.
Installing it will result in installing the most recent version of `mqrpy`.
For now, the version of this package will match the current version of `mqrpy`.

Instead of installing this package, prefer to use `mqrpy` directly:<br>
See [`mqrpy`](https://pypi.org/project/mqrpy/).

Documentation
-------------
The documentation, including a user guide and API reference is at https://nklsxn.github.io/mqr/latest/.

A set of detailed examples is available in the repository https://github.com/nklsxn/mqrpy-guide.

License
-------
This package is provided under the BSD License (3-clause).

Credit
------
Copyright 2024-2025 Nikolas Crossan and Kevin Otto

Supported by the University of Melbourne<br>
Department of Mechanical Engineering
